/* eslint-disable no-console */

"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _net = require("net");

var _net2 = _interopRequireDefault(_net);

var _colors = require("colors");

var _colors2 = _interopRequireDefault(_colors);

var _options = require("./options");

var _options2 = _interopRequireDefault(_options);

var _oscClient = require("./osc-client");

var _oscClient2 = _interopRequireDefault(_oscClient);

var _oscServer = require("./osc-server");

var _oscServer2 = _interopRequireDefault(_oscServer);

var _utils = require("./utils");

var _utils2 = _interopRequireDefault(_utils);

var quiet = false;

function print() {
  if (!quiet) {
    console.log.apply(console, arguments);
  }
}

function printError(e) {
  print(_colors2["default"].red.underline(e.toString()));
}

function help() {
  print(_options2["default"].generateHelp());
}

function printVersion() {
  var version = require("../package.json").version;

  print("v" + version);
}

function runServer(opts) {
  var server = (0, _oscServer2["default"])(_net2["default"].createServer());

  server.listen(opts.port, function () {
    print("Listening on port %d", opts.port);
  });

  server.on("osc-hub:message", function (msg) {
    print(_colors2["default"].green(">> %s"), _utils2["default"].prettify(msg));
  });

  server.on("osc-hub:error", printError);

  return server;
}

function runClient(opts) {
  var connection = _net2["default"].connect({ host: opts.host, port: opts.port });
  var client = (0, _oscClient2["default"])(connection, opts);

  client.on("connect", function () {
    print("connected: %s:%s", opts.host, opts.port);
  });

  client.on("error", function (msg) {
    printError(msg);
    if (msg.code === "ECONNREFUSED") {
      setTimeout(function () {
        connection.connect({ host: opts.host, port: opts.port });
      }, 1000);
    }
  });

  client.on("end", function () {
    setTimeout(function () {
      connection.connect({ host: opts.host, port: opts.port });
    }, 1000);
  });

  client.on("osc-hub:send", function (msg) {
    print(_colors2["default"].yellow(">> %s"), _utils2["default"].prettify(msg));
  });

  client.on("osc-hub:receive", function (msg) {
    print(_colors2["default"].cyan("<< %s"), _utils2["default"].prettify(msg));
  });

  client.on("osc-hub:error", printError);

  return client;
}

exports["default"] = {
  run: function run(argv) {
    var opts = _options2["default"].parse(argv);

    if (opts.help) {
      return help();
    }

    quiet = opts.quiet;

    if (opts.version) {
      return printVersion();
    }

    if (opts.server) {
      return runServer(opts);
    }

    return runClient(opts);
  }
};
module.exports = exports["default"];