"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var _dgram = require("dgram");

var _dgram2 = _interopRequireDefault(_dgram);

var _oscMsg = require("osc-msg");

var _oscMsg2 = _interopRequireDefault(_oscMsg);

var _utils = require("./utils");

var _utils2 = _interopRequireDefault(_utils);

function setupSendToOscHub(client, sendPorts) {
  function sendToOscHub(data) {
    var msg = _oscMsg2["default"].fromBuffer(data);

    if (!msg.error) {
      client.write(data, function () {
        client.emit("osc-hub:send", msg, data);
      });
    } else {
      client.emit("osc-hub:error", _utils2["default"].createTypeError("invalid data", { data: data }));
    }
  }

  var sockets = sendPorts.map(function (port) {
    var socket = _dgram2["default"].createSocket("udp4");

    socket.on("message", sendToOscHub);
    socket.on("error", function (e) {
      client.emit("osc-hub:error", e);
    });

    socket.bind(port);

    return socket;
  });

  client.oschubSockets = sockets;
}

function setupRecvFromOscHub(client, recvPorts) {
  var sender = _dgram2["default"].createSocket("udp4");

  client.on("data", function (data) {
    var msg = _oscMsg2["default"].fromBuffer(data);
    var targets = recvPorts.slice();

    function loop() {
      if (targets.length === 0) {
        client.emit("osc-hub:receive", msg, data);
      } else {
        sender.send(data, 0, data.length, targets.shift(), "127.0.0.1", loop);
      }
    }

    if (!msg.error) {
      loop();
    } else {
      client.emit("osc-hub:error", _utils2["default"].createTypeError("invalid data", { data: data }));
    }
  });
}

exports["default"] = function (client) {
  var opts = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

  setupSendToOscHub(client, _utils2["default"].toArray(opts.send));
  setupRecvFromOscHub(client, _utils2["default"].toArray(opts.receive));

  return client;
};

module.exports = exports["default"];